==> gd32f1-0.4.0.crate: gd32f1-0.4.0/src/gd32f190/dac/dacc_r12dh.rs <==
#[doc = "Register `DACC_R12DH` reader"]
pub struct R(crate::R<DACC_R12DH_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DACC_R12DH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<DACC_R12DH_SPEC>> for R {
    fn from(reader: crate::R<DACC_R12DH_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DACC_R12DH` writer"]
pub struct W(crate::W<DACC_R12DH_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DACC_R12DH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<DACC_R12DH_SPEC>> for W {
    fn from(writer: crate::W<DACC_R12DH_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `DAC0_DH` reader - DAC0 12-bit right-aligned data"]
pub struct DAC0_DH_R(crate::FieldReader<u16, u16>);
impl DAC0_DH_R {
    pub(crate) fn new(bits: u16) -> Self {
        DAC0_DH_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DAC0_DH_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DAC0_DH` writer - DAC0 12-bit right-aligned data"]
pub struct DAC0_DH_W<'a> {
    w: &'a mut W,
}
impl<'a> DAC0_DH_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
#[doc = "Field `DAC1_DH` reader - DAC1 12-bit right-aligned data"]
pub struct DAC1_DH_R(crate::FieldReader<u16, u16>);
impl DAC1_DH_R {
    pub(crate) fn new(bits: u16) -> Self {
        DAC1_DH_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DAC1_DH_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DAC1_DH` writer - DAC1 12-bit right-aligned data"]
pub struct DAC1_DH_W<'a> {
    w: &'a mut W,
}
impl<'a> DAC1_DH_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0fff << 16)) | ((value as u32 & 0x0fff) << 16);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:11 - DAC0 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac0_dh(&self) -> DAC0_DH_R {
        DAC0_DH_R::new((self.bits & 0x0fff) as u16)
    }
    #[doc = "Bits 16:27 - DAC1 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac1_dh(&self) -> DAC1_DH_R {
        DAC1_DH_R::new(((self.bits >> 16) & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:11 - DAC0 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac0_dh(&mut self) -> DAC0_DH_W {
        DAC0_DH_W { w: self }
    }
    #[doc = "Bits 16:27 - DAC1 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac1_dh(&mut self) -> DAC1_DH_W {
        DAC1_DH_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DAC concurrent mode 12-bit right-aligned data holding register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dacc_r12dh](index.html) module"]
pub struct DACC_R12DH_SPEC;
impl crate::RegisterSpec for DACC_R12DH_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dacc_r12dh::R](R) reader structure"]
impl crate::Readable for DACC_R12DH_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dacc_r12dh::W](W) writer structure"]
impl crate::Writable for DACC_R12DH_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DACC_R12DH to value 0"]
impl crate::Resettable for DACC_R12DH_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f190/dac/dacc_r12dh.rs <==
#[doc = "Register `DACC_R12DH` reader"]
pub struct R(crate::R<DACC_R12DH_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DACC_R12DH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DACC_R12DH_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DACC_R12DH_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DACC_R12DH` writer"]
pub struct W(crate::W<DACC_R12DH_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DACC_R12DH_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<DACC_R12DH_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<DACC_R12DH_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `DAC0_DH` reader - DAC0 12-bit right-aligned data"]
pub struct DAC0_DH_R(crate::FieldReader<u16, u16>);
impl DAC0_DH_R {
    pub(crate) fn new(bits: u16) -> Self {
        DAC0_DH_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DAC0_DH_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DAC0_DH` writer - DAC0 12-bit right-aligned data"]
pub struct DAC0_DH_W<'a> {
    w: &'a mut W,
}
impl<'a> DAC0_DH_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
#[doc = "Field `DAC1_DH` reader - DAC1 12-bit right-aligned data"]
pub struct DAC1_DH_R(crate::FieldReader<u16, u16>);
impl DAC1_DH_R {
    pub(crate) fn new(bits: u16) -> Self {
        DAC1_DH_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DAC1_DH_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DAC1_DH` writer - DAC1 12-bit right-aligned data"]
pub struct DAC1_DH_W<'a> {
    w: &'a mut W,
}
impl<'a> DAC1_DH_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0fff << 16)) | ((value as u32 & 0x0fff) << 16);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:11 - DAC0 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac0_dh(&self) -> DAC0_DH_R {
        DAC0_DH_R::new((self.bits & 0x0fff) as u16)
    }
    #[doc = "Bits 16:27 - DAC1 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac1_dh(&self) -> DAC1_DH_R {
        DAC1_DH_R::new(((self.bits >> 16) & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:11 - DAC0 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac0_dh(&mut self) -> DAC0_DH_W {
        DAC0_DH_W { w: self }
    }
    #[doc = "Bits 16:27 - DAC1 12-bit right-aligned data"]
    #[inline(always)]
    pub fn dac1_dh(&mut self) -> DAC1_DH_W {
        DAC1_DH_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DAC concurrent mode 12-bit right-aligned data holding register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dacc_r12dh](index.html) module"]
pub struct DACC_R12DH_SPEC;
impl crate::RegisterSpec for DACC_R12DH_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dacc_r12dh::R](R) reader structure"]
impl crate::Readable for DACC_R12DH_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dacc_r12dh::W](W) writer structure"]
impl crate::Writable for DACC_R12DH_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DACC_R12DH to value 0"]
impl crate::Resettable for DACC_R12DH_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
